kanzi::inherits_constraint

Trait Inheritable

pub unsafe trait Inheritable: Sized {
    // Provided methods
    unsafe fn downcast_unchecked<T>(self) -> T
       where T: Inherits<Self> { ... }
    unsafe fn downcast_unchecked_ref<T>(&self) -> &T
       where T: Inherits<Self> { ... }
}
Represents Kanzi classes that can be inherited from.

This implies that such classes can be downcast to a more specific type.

Safety

Inhertiable is an internal trait and shouldn’t be implemented by users directly.

Provided Methods

unsafe fn downcast_unchecked<T>(self) -> T
where T: Inherits<Self>,

Downcast the object to a more specific type.

Safety

This is a wrapper over std::mem::transmute_copy with a bit more specific types. All of the safety requirements for transmute_copy apply here as well.

unsafe fn downcast_unchecked_ref<T>(&self) -> &T
where T: Inherits<Self>,

Downcast the object reference to a more specific type.

Safety

This is a wrapper over std::mem::transmute with a bit more specific types. All of the safety requirements for transmute apply here as well.

Object Safety

This trait is not object safe.

Implementors



impl Inheritable for AbstractBinding



impl Inheritable for Action



impl Inheritable for ActionBase



impl Inheritable for Activity2D



impl Inheritable for Activity3D



impl Inheritable for ActivityCodeBehind



impl Inheritable for ActivityConcept



impl Inheritable for ActivityElement



impl Inheritable for ActivityHostConcept



impl Inheritable for AnimationBindingProcessor



impl Inheritable for AnimationPlayer



impl Inheritable for AnimationResource



impl Inheritable for ApplyAction



impl Inheritable for ApplyActivationAction



impl Inheritable for ApplyPropertyAction



impl Inheritable for BinaryResource



impl Inheritable for BindingProcessor



impl Inheritable for BitmapFontFile



impl Inheritable for BlitRenderPass



impl Inheritable for BlurEffect2D



impl Inheritable for Brush



impl Inheritable for Button2D



impl Inheritable for Button3D



impl Inheritable for ButtonConcept



impl Inheritable for CallbackBindingProcessor



impl Inheritable for Camera



impl Inheritable for ClearRenderPass



impl Inheritable for ClickConcept



impl Inheritable for ClickManipulator



impl Inheritable for ClickManipulatorComponent



impl Inheritable for CodeBehind



impl Inheritable for ColorBrush



impl Inheritable for CompositionBrush



impl Inheritable for CompositionTargetRenderPass



impl Inheritable for Condition



impl Inheritable for ContentBrush



impl Inheritable for ContentLayout2D



impl Inheritable for ContentLayout3D



impl Inheritable for ContentLayoutConcept



impl Inheritable for CubeMapRenderPass



impl Inheritable for DataContext



impl Inheritable for DataDrivenExclusiveActivityHost2D



impl Inheritable for DataDrivenExclusiveActivityHost3D



impl Inheritable for DataDrivenExclusiveActivityHostConcept



impl Inheritable for DataObjectList



impl Inheritable for DataSource



impl Inheritable for DataSourceListItemGenerator2D



impl Inheritable for DataSourceListItemGenerator3D



impl Inheritable for DataTrigger



impl Inheritable for DataTriggerComponent



impl Inheritable for DispatchMessageAction



impl Inheritable for DockLayout2D



impl Inheritable for DockLayout3D



impl Inheritable for DockLayoutConcept



impl Inheritable for DragAndDropManipulator



impl Inheritable for DrawObjectsRenderPass



impl Inheritable for DrawObjectsWithMaterialRenderPass



impl Inheritable for EffectStack2D



impl Inheritable for EmptyNode2D



impl Inheritable for EmptyNode3D



impl Inheritable for ExclusiveActivityHost2D



impl Inheritable for ExclusiveActivityHost3D



impl Inheritable for ExclusiveActivityHostConcept



impl Inheritable for ExpressionBindingProcessor



impl Inheritable for ExpressionCondition



impl Inheritable for FloatValueAccumulator



impl Inheritable for FlowLayout2D



impl Inheritable for FlowLayout3D



impl Inheritable for FlowLayoutConcept



impl Inheritable for FocusNavigationManipulator



impl Inheritable for FontFamily



impl Inheritable for FontFile



impl Inheritable for FontStyleConcept



impl Inheritable for ForwardingAction



impl Inheritable for Framebuffer



impl Inheritable for GPUResource



impl Inheritable for GatherLightsRenderPass



impl Inheritable for GatherNearestLightsRenderPass



impl Inheritable for GridLayout2D



impl Inheritable for GridLayout3D



impl Inheritable for GridLayoutConcept



impl Inheritable for GridListBox2D



impl Inheritable for GridListBox3D



impl Inheritable for GridListBoxConcept



impl Inheritable for Image2D



impl Inheritable for InputManipulator



impl Inheritable for Instantiator3D



impl Inheritable for InstructionBindingProcessor



impl Inheritable for IntValueAccumulator



impl Inheritable for KeyManipulator



impl Inheritable for KeyManipulatorComponent



impl Inheritable for LegacyRenderPass



impl Inheritable for LevelOfDetail3D



impl Inheritable for Light



impl Inheritable for ListBoxConcept



impl Inheritable for ListBoxItemContainer2D



impl Inheritable for ListBoxItemContainer3D



impl Inheritable for ListBoxItemContainer



impl Inheritable for ListBoxItemContainerGenerator3D



impl Inheritable for ListBoxItemGenerator2D



impl Inheritable for ListBoxItemGenerator3D



impl Inheritable for ListBoxScrollingConcept



impl Inheritable for LongPressManipulator



impl Inheritable for LongPressManipulatorComponent



impl Inheritable for MaskEffect2D



impl Inheritable for Material



impl Inheritable for MaterialBrush



impl Inheritable for MaterialSetupRenderPass



impl Inheritable for Mesh



impl Inheritable for MessageArguments



impl Inheritable for MessageTrigger



impl Inheritable for MipmapGenerationConcept



impl Inheritable for Model3D



impl Inheritable for Morph



impl Inheritable for MorphWeightTimeline



impl Inheritable for MoveFocusAction



impl Inheritable for MultiClickManipulator



impl Inheritable for MultiClickManipulatorComponent



impl Inheritable for NavigationManipulator



impl Inheritable for NavigationManipulatorComponent



impl Inheritable for NinePatchImage2D



impl Inheritable for Node2D



impl Inheritable for Node3D



impl Inheritable for Node



impl Inheritable for NodeComponent



impl Inheritable for NodeEffect2D



impl Inheritable for NodeEffectPrefab2D



impl Inheritable for NodeListRenderPass



impl Inheritable for NullBrush



impl Inheritable for Object



impl Inheritable for ObjectSource



impl Inheritable for OnAttachedTrigger



impl Inheritable for OnPropertyChangedTrigger



impl Inheritable for OutlineEffect2D



impl Inheritable for Page



impl Inheritable for PageHost



impl Inheritable for PageTransitionCollection



impl Inheritable for PanManipulator



impl Inheritable for PanManipulatorComponent



impl Inheritable for ParallelActivityHost2D



impl Inheritable for ParallelActivityHost3D



impl Inheritable for ParallelActivityHostConcept



impl Inheritable for ParallelTimeline



impl Inheritable for PinchManipulator



impl Inheritable for PipelineStateRenderPass



impl Inheritable for Portal



impl Inheritable for PrefabTemplate



impl Inheritable for PrefabTemplateNode



impl Inheritable for PrefabView2D



impl Inheritable for PrefabView3D



impl Inheritable for PrefabViewConcept



impl Inheritable for ProgressiveRenderingViewport2D



impl Inheritable for PropertyAnimationTimeline



impl Inheritable for PropertyDrivenAnimationPlayer



impl Inheritable for PropertyFieldAnimationTimeline



impl Inheritable for PropertyTargetEasingInterpolator



impl Inheritable for PropertyTargetInterpolator



impl Inheritable for RangeAccumulateBindingProcessor



impl Inheritable for RangeBindingProcessor



impl Inheritable for RangeConcept



impl Inheritable for RenderPass



impl Inheritable for RenderPassPrefab



impl Inheritable for RenderPassView



impl Inheritable for Renderbuffer



impl Inheritable for Resource



impl Inheritable for ResourceBindingProcessor



impl Inheritable for ResourceDictionary



impl Inheritable for ResourceDictionarySelector



impl Inheritable for Scene



impl Inheritable for Screen



impl Inheritable for ScrollView2D



impl Inheritable for ScrollView3D



impl Inheritable for ScrollViewConcept



impl Inheritable for SetPropertyAction



impl Inheritable for ShaderProgram



impl Inheritable for ShadowEffect2D



impl Inheritable for Slider2D



impl Inheritable for Slider3D



impl Inheritable for SliderConcept



impl Inheritable for StackLayout2D



impl Inheritable for StackLayout3D



impl Inheritable for StackLayoutConcept



impl Inheritable for StateManager



impl Inheritable for Style



impl Inheritable for Surface



impl Inheritable for TextBlock2D



impl Inheritable for TextBlock3D



impl Inheritable for TextBlockConcept



impl Inheritable for TextBox2D



impl Inheritable for TextBox3D



impl Inheritable for TextBoxConcept



impl Inheritable for TextConcept



impl Inheritable for TextInputManipulator



impl Inheritable for TextResource



impl Inheritable for Texture



impl Inheritable for TextureBrush



impl Inheritable for Timeline



impl Inheritable for TimelineResource



impl Inheritable for TimerTrigger



impl Inheritable for ToggleButton2D



impl Inheritable for ToggleButton3D



impl Inheritable for ToggleButtonGroup2D



impl Inheritable for ToggleButtonGroup3D



impl Inheritable for ToggleButtonGroupConcept



impl Inheritable for Trajectory



impl Inheritable for TrajectoryLayout2D



impl Inheritable for TrajectoryLayout3D



impl Inheritable for TrajectoryLayoutConcept



impl Inheritable for TrajectoryListBox3D



impl Inheritable for Trigger



impl Inheritable for TrySetFocusAction



impl Inheritable for ValueAccumulatorBase



impl Inheritable for ValueControlledExclusiveActivityHostConcept



impl Inheritable for Viewport2D



impl Inheritable for Viewport3D



impl Inheritable for WriteLogAction



impl<T> Inheritable for DataObject<T>