kanzi::autogen::ui::node::exclusive_activity_host2d

Trait IValueControlledExclusiveActivityHostConcept

pub trait IValueControlledExclusiveActivityHostConcept: Inherits<Object> + Inherits<ValueControlledExclusiveActivityHostConcept> {
    // Provided methods
    fn get_controller_property(&self) -> Result<KanziString, Error> { ... }
    fn set_controller_property(
        &self,
        value: impl AsRef<KanziStr>,
    ) -> Result<(), Error> { ... }
    fn get_data_source_controller_property_path(
        &self,
    ) -> Result<KanziString, Error> { ... }
    fn set_data_source_controller_property_path(
        &self,
        value: impl AsRef<KanziStr>,
    ) -> Result<(), Error> { ... }
}
Base class for the Exclusive Activity Host classes. This class defines the types and properties for the Exclusive Activity Host classes for which the activation of the child Activities is controlled by a property or a DataObject value. See: ExclusiveActivityHost2D, ExclusiveActivityHost3D.

Since

Kanzi 3.9.0

Provided Methods

Object Safety

This trait is not object safe.

Implementors