kanzi::autogen::ui::node::text_block3d

Trait ITextBlockConcept

pub trait ITextBlockConcept: Inherits<Object> + Inherits<TextBlockConcept> {
    // Provided methods
    fn get_word_wrap(&self) -> Result<bool, Error> { ... }
    fn set_word_wrap(&self, value: bool) -> Result<(), Error> { ... }
}
Base class for the Text Block nodes that you can use to show a small amount of text in your application.

This class defines the property types used by the Text Block nodes.

Provided Methods

Object Safety

This trait is not object safe.

Implementors