Enum ActivityStatus
#[repr(i32)]pub enum ActivityStatus {
Active = 0,
Inactive = 1,
Activating = 2,
Deactivating = 3,
}Expand description
Legacy version of enum “kanzi.ActivityConcept.Status”. Defines possible states of an Activity. Activity Host nodes can activate and deactivate their child Activities. This enumeration defines the possible states of an Activity during the the process of activation and deactivation. You can use this functionality to react to changes in Activity status in your application code and in Kanzi Studio. See: Activity, StatusProperty
Variants
Active = 0
The Activity is active. In an Exclusive Activity Host only one child Activity can be in the Active state at a time. In a Parallel Activity Host more than one Activity can be in the Active state at the same time, therefore any Activity can be in any state.
Inactive = 1
The Activity is inactive. Inactive Activities do not show their content.
Activating = 2
The Activity is transitioning into the active state. In an Exclusive Activity Host while one Activity is in Activating state, another Activity can be in the Deactivating state at the same time. In a Parallel Activity Host more than one Activity can be in the Active state at the same time, therefore any Activity can be in any state.
Deactivating = 3
The Activity is transitioning into the inactive state. In an Exclusive Activity Host while one Activity is in Deactivating state, another Activity can at the same time be in the Activating state. In a Parallel Activity Host more than one Activity can be in the Active state at the same time, therefore any Activity can be in any state.
Implementations
impl ActivityStatus
impl ActivityStatus
pub fn as_str(self) -> &'static str
pub fn convert(num: i32) -> ActivityStatus