Struct HIT_TESTABLE_PROPERTY
pub struct HIT_TESTABLE_PROPERTY { /* private fields */ }Expand description
When enabled, the node can be hit tested. Enabling Hit Testable for a 2D node enables hit testing only for that node. Enabling Hit Testable for a 3D node enables hit testing also for the child nodes. Kanzi hit tests 3D nodes using the default Camera node or the Hit Test Camera node of the active Scene node.
Methods from Deref<Target = PropertyType<bool>>
pub fn as_ptr(&self) -> *mut PropertyTypeWrapper
pub fn get_native(&self) -> Result<NonNull<c_void>, Error>
pub fn get_native(&self) -> Result<NonNull<c_void>, Error>
Gets a pointer to the backing C++ instance.
pub fn compare(&self, rhs: &PropertyType<T>) -> Result<bool, Error>
pub fn compare(&self, rhs: &PropertyType<T>) -> Result<bool, Error>
Compares two property types.
pub fn is_inherited(&self) -> Result<bool, Error>
pub fn get_change_flags(&self) -> Result<ChangeFlags, Error>
pub fn get_data_type(&self) -> Result<PropertyDataType, Error>
pub fn get_name(&self) -> Result<KanziString, Error>
pub fn get_name(&self) -> Result<KanziString, Error>
Gets name of the property type.
pub fn get_editor_info(&self) -> Result<Option<EditorInfo>, Error>
pub fn get_editor_info(&self) -> Result<Option<EditorInfo>, Error>
Gets editor info for the property type.
pub fn cast_ref<T>(&self) -> Result<Option<&PropertyType<T>>, Error>where
T: PropertyTypeConstraint,
pub fn cast_ref<T>(&self) -> Result<Option<&PropertyType<T>>, Error>where
T: PropertyTypeConstraint,
Casts AbstractPropertyType reference to a more concrete type.
pub unsafe fn cast_ref_unchecked<T>(&self) -> &PropertyType<T>where
T: PropertyTypeConstraint,
pub unsafe fn cast_ref_unchecked<T>(&self) -> &PropertyType<T>where
T: PropertyTypeConstraint,
Casts AbstractPropertyType reference to a more concrete type.
Safety
The caller must ensure that T matches the internal property type.
pub fn debug_string(&self, object: &Object) -> Result<String, Error>
pub fn debug_string(&self, object: &Object) -> Result<String, Error>
Constructs a debug string containing the property value of a provided Object.
pub fn as_abstract(&self) -> &PropertyType<()>
pub fn as_abstract(&self) -> &PropertyType<()>
Casts a PropertyType reference to its abstract representation.
pub fn get_default_value(
&self,
) -> Result<<T as VariantConstraint>::RetArg, Error>
pub fn get_default_value( &self, ) -> Result<<T as VariantConstraint>::RetArg, Error>
Gets the default value of a property type. When no other value is available, property functions return the default value.