Struct TRUNCATION_PROPERTY
pub struct TRUNCATION_PROPERTY { /* private fields */ }Expand description
Sets how Kanzi truncates text when either Truncation or Overflow property is set and the text does not fit in this node:
- None disables text truncation.
- At character truncates text character by character. Default value.
- At word truncates text by entire words.
Kanzi truncates text to fit within the vertical and horizontal limits of the control. If there is not enough vertical space to fit a single line of text, Kanzi truncates all text and does not show overflow characters.
Methods from Deref<Target = PropertyType<Truncation>>
pub fn as_ptr(&self) -> *mut PropertyTypeWrapper
pub fn get_native(&self) -> Result<NonNull<c_void>, Error>
pub fn get_native(&self) -> Result<NonNull<c_void>, Error>
Gets a pointer to the backing C++ instance.
pub fn compare(&self, rhs: &PropertyType<T>) -> Result<bool, Error>
pub fn compare(&self, rhs: &PropertyType<T>) -> Result<bool, Error>
Compares two property types.
pub fn is_inherited(&self) -> Result<bool, Error>
pub fn get_change_flags(&self) -> Result<ChangeFlags, Error>
pub fn get_data_type(&self) -> Result<PropertyDataType, Error>
pub fn get_name(&self) -> Result<KanziString, Error>
pub fn get_name(&self) -> Result<KanziString, Error>
Gets name of the property type.
pub fn get_editor_info(&self) -> Result<Option<EditorInfo>, Error>
pub fn get_editor_info(&self) -> Result<Option<EditorInfo>, Error>
Gets editor info for the property type.
pub fn cast_ref<T>(&self) -> Result<Option<&PropertyType<T>>, Error>where
T: PropertyTypeConstraint,
pub fn cast_ref<T>(&self) -> Result<Option<&PropertyType<T>>, Error>where
T: PropertyTypeConstraint,
Casts AbstractPropertyType reference to a more concrete type.
pub unsafe fn cast_ref_unchecked<T>(&self) -> &PropertyType<T>where
T: PropertyTypeConstraint,
pub unsafe fn cast_ref_unchecked<T>(&self) -> &PropertyType<T>where
T: PropertyTypeConstraint,
Casts AbstractPropertyType reference to a more concrete type.
Safety
The caller must ensure that T matches the internal property type.
pub fn debug_string(&self, object: &Object) -> Result<String, Error>
pub fn debug_string(&self, object: &Object) -> Result<String, Error>
Constructs a debug string containing the property value of a provided Object.
pub fn as_abstract(&self) -> &PropertyType<()>
pub fn as_abstract(&self) -> &PropertyType<()>
Casts a PropertyType reference to its abstract representation.
pub fn get_default_value(
&self,
) -> Result<<T as VariantConstraint>::RetArg, Error>
pub fn get_default_value( &self, ) -> Result<<T as VariantConstraint>::RetArg, Error>
Gets the default value of a property type. When no other value is available, property functions return the default value.