kanzi

Trait IStackLayoutConcept

pub trait IStackLayoutConcept: Inherits<Object> + Inherits<StackLayoutConcept> {
    // Provided methods
    fn get_direction(&self) -> Result<LayoutDirection, Error> { ... }
    fn set_direction(&self, value: LayoutDirection) -> Result<(), Error> { ... }
    fn get_reversed(&self) -> Result<bool, Error> { ... }
    fn set_reversed(&self, value: bool) -> Result<(), Error> { ... }
}
Stack layout concept base class.

Note: Do not use this class directly. To use a stack layout in your application use StackLayout3D or StackLayout2D.

StackLayoutConcept defines the data and property types used to implement a stack layout. StackLayoutConceptImpl derives from StackLayoutConcept to provide the functionality to implement a stack layout. To implement a custom stack layout derive from StackLayoutConceptImpl.

Provided Methods

Object Safety

This trait is not object safe.

Implementors