kanzi

Trait IGridLayoutConcept

pub trait IGridLayoutConcept: Inherits<Object> + Inherits<GridLayoutConcept> {
Show 14 methods // Provided methods fn get_direction(&self) -> Result<GridDirection, Error> { ... } fn set_direction(&self, value: GridDirection) -> Result<(), Error> { ... } fn get_column_definitions(&self) -> Result<KanziString, Error> { ... } fn set_column_definitions( &self, value: impl AsRef<KanziStr>, ) -> Result<(), Error> { ... } fn get_row_definitions(&self) -> Result<KanziString, Error> { ... } fn set_row_definitions( &self, value: impl AsRef<KanziStr>, ) -> Result<(), Error> { ... } fn get_column(&self) -> Result<i32, Error> { ... } fn set_column(&self, value: i32) -> Result<(), Error> { ... } fn get_column_span(&self) -> Result<i32, Error> { ... } fn set_column_span(&self, value: i32) -> Result<(), Error> { ... } fn get_row(&self) -> Result<i32, Error> { ... } fn set_row(&self, value: i32) -> Result<(), Error> { ... } fn get_row_span(&self) -> Result<i32, Error> { ... } fn set_row_span(&self, value: i32) -> Result<(), Error> { ... }
}
Base class for the Grid Layout nodes.

Grid Layout nodes arrange their items in a grid of cells. The grid node contains the definition for grid: the number and size of rows and columns. The grid items contain the coordinates of their cell, and the number of cells the item spans.

Provided Methods

Object Safety

This trait is not object safe.

Implementors