kanzi

Trait ITextConcept

pub trait ITextConcept: Inherits<Object> + Inherits<TextConcept> {
Show 26 methods // Provided methods fn get_font_color(&self) -> Result<ColorRGBA, Error> { ... } fn set_font_color(&self, value: ColorRGBA) -> Result<(), Error> { ... } fn get_font_material(&self) -> Result<Option<Weak<Resource>>, Error> { ... } fn set_font_material(&self, value: Option<&Resource>) -> Result<(), Error> { ... } fn get_text(&self) -> Result<KanziString, Error> { ... } fn set_text(&self, value: impl AsRef<KanziStr>) -> Result<(), Error> { ... } fn get_text_horizontal_alignment( &self, ) -> Result<TextHorizontalAlignment, Error> { ... } fn set_text_horizontal_alignment( &self, value: TextHorizontalAlignment, ) -> Result<(), Error> { ... } fn get_text_vertical_alignment( &self, ) -> Result<TextVerticalAlignment, Error> { ... } fn set_text_vertical_alignment( &self, value: TextVerticalAlignment, ) -> Result<(), Error> { ... } fn get_horizontal_padding(&self) -> Result<Vector2, Error> { ... } fn set_horizontal_padding(&self, value: Vector2) -> Result<(), Error> { ... } fn get_vertical_padding(&self) -> Result<Vector2, Error> { ... } fn set_vertical_padding(&self, value: Vector2) -> Result<(), Error> { ... } fn get_overflow(&self) -> Result<KanziString, Error> { ... } fn set_overflow(&self, value: impl AsRef<KanziStr>) -> Result<(), Error> { ... } fn get_truncation(&self) -> Result<Truncation, Error> { ... } fn set_truncation(&self, value: Truncation) -> Result<(), Error> { ... } fn get_truncation_direction(&self) -> Result<TruncationDirection, Error> { ... } fn set_truncation_direction( &self, value: TruncationDirection, ) -> Result<(), Error> { ... } fn get_remove_side_bearings(&self) -> Result<bool, Error> { ... } fn set_remove_side_bearings(&self, value: bool) -> Result<(), Error> { ... } fn get_horizontal_fit(&self) -> Result<bool, Error> { ... } fn set_horizontal_fit(&self, value: bool) -> Result<(), Error> { ... } fn get_horizontal_fit_scale_limits(&self) -> Result<Vector2, Error> { ... } fn set_horizontal_fit_scale_limits( &self, value: Vector2, ) -> Result<(), Error> { ... }
}
TextConcept is the base class for the nodes that implement text rendering.

This class defines the data and property types used to implement the text rendering nodes, such as TextBlock2D, TextBlock3D, TextBox2D, and TextBox3D.

Since

Kanzi 3.9.0

Provided Methods

fn get_font_color(&self) -> Result<ColorRGBA, Error>

fn set_font_color(&self, value: ColorRGBA) -> Result<(), Error>

fn get_font_material(&self) -> Result<Option<Weak<Resource>>, Error>

fn set_font_material(&self, value: Option<&Resource>) -> Result<(), Error>

fn get_text(&self) -> Result<KanziString, Error>

fn set_text(&self, value: impl AsRef<KanziStr>) -> Result<(), Error>

fn get_text_horizontal_alignment( &self, ) -> Result<TextHorizontalAlignment, Error>

fn set_text_horizontal_alignment( &self, value: TextHorizontalAlignment, ) -> Result<(), Error>

fn get_text_vertical_alignment(&self) -> Result<TextVerticalAlignment, Error>

fn set_text_vertical_alignment( &self, value: TextVerticalAlignment, ) -> Result<(), Error>

fn get_horizontal_padding(&self) -> Result<Vector2, Error>

fn set_horizontal_padding(&self, value: Vector2) -> Result<(), Error>

fn get_vertical_padding(&self) -> Result<Vector2, Error>

fn set_vertical_padding(&self, value: Vector2) -> Result<(), Error>

fn get_overflow(&self) -> Result<KanziString, Error>

fn set_overflow(&self, value: impl AsRef<KanziStr>) -> Result<(), Error>

fn get_truncation(&self) -> Result<Truncation, Error>

fn set_truncation(&self, value: Truncation) -> Result<(), Error>

fn get_truncation_direction(&self) -> Result<TruncationDirection, Error>

fn set_truncation_direction( &self, value: TruncationDirection, ) -> Result<(), Error>

fn get_remove_side_bearings(&self) -> Result<bool, Error>

fn set_remove_side_bearings(&self, value: bool) -> Result<(), Error>

fn get_horizontal_fit(&self) -> Result<bool, Error>

fn set_horizontal_fit(&self, value: bool) -> Result<(), Error>

fn get_horizontal_fit_scale_limits(&self) -> Result<Vector2, Error>

fn set_horizontal_fit_scale_limits(&self, value: Vector2) -> Result<(), Error>

Object Safety

This trait is not object safe.

Implementors