kanzi

Trait IListBoxItemContainer

pub trait IListBoxItemContainer: Inherits<Object> + Inherits<ListBoxItemContainer> {
    // Provided methods
    fn get_item_index(&self) -> Result<i32, Error> { ... }
    fn set_item_index(&self, value: i32) -> Result<(), Error> { ... }
    fn get_selected(&self) -> Result<bool, Error> { ... }
    fn set_selected(&self, value: bool) -> Result<(), Error> { ... }
}
Use the List %Box Item Container prefab to create common functionality and decoration for all items in a List %Box.

Kanzi creates a List %Box Item Container for each List %Box item. To set the List %Box Item Container prefab for the items in a List %Box, use the ListBoxConcept::ItemContainerTemplateProperty property in that List %Box.

List %Box item placement

To set where Kanzi places each List %Box item inside the List %Box Item Container prefab:

  • In the List %Box Item Container prefab create a Content Layout node.
  • In the resource dictionary of the List %Box Item Container prefab create an alias.
  • Name the alias “$layout” and set it to point to the Content Layout node in the List %Box Item Container prefab.

Kanzi now places the List %Box item in the Content Layout node to which the alias points. If you do not specify the $layout alias that points to the Content Layout node in the List %Box Item Container prefab, Kanzi places the List %Box item as the last child of the List %Box Item Container node.

Enabling the multi-click gesture

To enable the double-click gesture for all items in a List %Box node, in the List %Box Item Container prefab set the ClickConcept::DoubleClickEnabledProperty to true.

Provided Methods

Object Safety

This trait is not object safe.

Implementors