kanzi

Trait IActivityElement

pub trait IActivityElement: Inherits<Object> + Inherits<ActivityElement> {
    // Provided methods
    fn get_attached(&self) -> Result<bool, Error> { ... }
    fn set_attached(&self, value: bool) -> Result<(), Error> { ... }
    fn get_preserve_history(&self) -> Result<bool, Error> { ... }
    fn set_preserve_history(&self, value: bool) -> Result<(), Error> { ... }
}
ActivityElement is the base class for all Activity and Activity Host classes.

ActivityElement provides the way to manipulate the activity graph in a uniform manner. ActivityElement provides this base functionality to all Activity and Activity Host classes:

  • Access the parent Activity Element.
  • Access the child Activity Host nodes.
  • Access the underlying Node object.
  • Code Behind.
  • Serialization and History Manager.

Provided Methods

Object Safety

This trait is not object safe.

Implementors