kanzi

Trait IFlowLayoutConcept

pub trait IFlowLayoutConcept: Inherits<Object> + Inherits<FlowLayoutConcept> {
    // Provided methods
    fn get_primary_direction(&self) -> Result<LayoutDirection, Error> { ... }
    fn set_primary_direction(&self, value: LayoutDirection) -> Result<(), Error> { ... }
    fn get_secondary_direction(&self) -> Result<LayoutDirection, Error> { ... }
    fn set_secondary_direction(
        &self,
        value: LayoutDirection,
    ) -> Result<(), Error> { ... }
}
Flow layout concept base class.

FlowLayoutConcept defines the data and property types used to implement a flow layout. FlowLayoutConceptImpl derives from StackLayoutConcept to provide the functionality to implement a flow layout. Do not use these classes directly. To use a flow layout in your application use FlowLayout3D or FlowLayout2D. To implement a custom flow layout derive from FlowLayoutConceptImpl.

Provided Methods

Object Safety

This trait is not object safe.

Implementors