kanzi

Trait IButtonConcept

pub trait IButtonConcept: Inherits<Object> + Inherits<ButtonConcept> {
Show 14 methods // Provided methods fn get_is_pressed(&self) -> Result<bool, Error> { ... } fn set_is_pressed(&self, value: bool) -> Result<(), Error> { ... } fn get_long_press_interval(&self) -> Result<f32, Error> { ... } fn set_long_press_interval(&self, value: f32) -> Result<(), Error> { ... } fn get_press_on_hover(&self) -> Result<bool, Error> { ... } fn set_press_on_hover(&self, value: bool) -> Result<(), Error> { ... } fn get_auto_click_interval(&self) -> Result<f32, Error> { ... } fn set_auto_click_interval(&self, value: f32) -> Result<(), Error> { ... } fn get_toggle_state(&self) -> Result<i32, Error> { ... } fn set_toggle_state(&self, value: i32) -> Result<(), Error> { ... } fn get_toggle_state_count(&self) -> Result<i32, Error> { ... } fn set_toggle_state_count(&self, value: i32) -> Result<(), Error> { ... } fn get_index_in_group(&self) -> Result<i32, Error> { ... } fn set_index_in_group(&self, value: i32) -> Result<(), Error> { ... }
}
Button nodes provide an area that receives key and touch input which Kanzi translates to state events. In addition to the area that receives input, the Toggle Button nodes provide a toggled state.

To disable a Button node set the Node::EnabledProperty to false. A disabled Button does not produce user events. To visually indicate the disabled state of a Button node, create a state manager and use the Node::EffectivelyEnabledProperty as its controller property. When Kanzi disables a Button node, it cancels the pressed state. Kanzi preserves the toggled state of a Toggle Button node when that Toggle Button is disabled.

Provided Methods

Object Safety

This trait is not object safe.

Implementors