kanzi::thread_object

Struct ThreadObject

pub struct ThreadObject<T>(/* private fields */);
ThreadObject represents a weak reference to a Kanzi object.

It exists primarily to allow Objects to be shared safely between multiple threads. To create a ThreadObject, call the ThreadObject::downgrade function. To convert a ThreadObject back to an owned object, call ThreadObject::upgrade.

Implementations



impl<T> ThreadObject<T>

pub fn upgrade(self, domain: &Domain) -> Result<Option<T>, Error>

Upgrades a ThreadObject to an owned object of the same type. If None is returned, the object has been destroyed.

pub fn unlock(self, domain: &Domain) -> Weak<T>

Unlocks a ThreadObject to a Weak object of the same type.

pub fn downgrade(object: T) -> ThreadObject<T>

Downgrades an object to a thread object of the same type.

pub fn downgrade_ref(object: &T) -> ThreadObject<T>

Downgrades an object reference to a thread object of the same type.

Methods from Deref<Target = ThreadObjectInner<T>>

pub fn upgrade_ref(&self, domain: &Domain) -> Result<Option<T>, Error>

Upgrades a ThreadObject reference to an owned object of the same type. If None is returned, the object has been destroyed.

pub fn unlock_ref(&self, domain: &Domain) -> Weak<T>

Unlocks a ThreadObject reference to a Weak reference of the same type.