Enum InputType
#[repr(i32)]pub enum InputType {
Default = 0,
Numeric = 1,
Email = 2,
Url = 3,
}Expand description
Variants
Default = 0
The input is the default of the input method.
Numeric = 1
The input is numeric.
Email = 2
The input requires a layout with characters used in email addresses.
Url = 3
The input requires a layout with characters used in URLs.
Implementations