Trait PropertyTypeConstraint
pub trait PropertyTypeConstraint: VariantConstraint { }Expand description
Used for statically defining the allowed types stored in PropertyTypes.
Object Safety
This trait is not object safe.
pub trait PropertyTypeConstraint: VariantConstraint { }Used for statically defining the allowed types stored in PropertyTypes.