Enum ErrorKind
pub enum ErrorKind {
CriticalError {
kind: ExecutionStatusKind,
msg: Option<KanziString>,
},
StaleObject,
ObjectNotFound,
InvalidArgument,
TypeMismatch,
IndexOutofBounds,
}Variants
CriticalError
All exceptions from Kanzi are converted into CriticalError.
Users are expected to propagate these errors to the top level,
as Kanzi may be left in an undefined state after an exception,
making continued execution of Kanzi potentially unsafe.
Fields
kind: ExecutionStatusKindUsed to provide more descriptive error messages. Matches an exception type caught by the bridge layer.
msg: Option<KanziString>Used to provide more descriptive error messages.
Optional error message extracted from a C++ exception with what() method.
StaleObject
The weak reference to the Kanzi object is no longer valid. The execution may continue.
ObjectNotFound
The requested property or object could not be found. The execution may continue.
InvalidArgument
The provided argument was not expected. The execution may continue.
TypeMismatch
Function succeeded and the object was returned, yet, downcasting it to a specified type failed. The execution may continue.
IndexOutofBounds
The provided index is out of bounds. The execution may continue.
Implementations
impl ErrorKind
impl ErrorKind
pub const fn as_sys_kind(&self) -> ExecutionStatusKind