Struct MessageTrigger
pub struct MessageTrigger(/* private fields */);Expand description
Message handler trigger.
Implementations
impl MessageTrigger
impl MessageTrigger
impl MessageTrigger
impl MessageTrigger
pub fn get_message_type(&self) -> Result<KanziString, Error>
pub fn get_message_type(&self) -> Result<KanziString, Error>
pub fn get_set_handled(&self) -> Result<bool, Error>
pub fn get_set_handled(&self) -> Result<bool, Error>
See: SET_HANDLED_PROPERTY
pub fn set_set_handled(&self, value: bool) -> Result<(), Error>
pub fn set_set_handled(&self, value: bool) -> Result<(), Error>
See: SET_HANDLED_PROPERTY
pub fn get_routing_mode(&self) -> Result<MessageRouting, Error>
pub fn get_routing_mode(&self) -> Result<MessageRouting, Error>
pub fn set_routing_mode(&self, value: MessageRouting) -> Result<(), Error>
pub fn set_routing_mode(&self, value: MessageRouting) -> Result<(), Error>
pub fn get_message_source(&self) -> Result<KanziString, Error>
pub fn get_message_source(&self) -> Result<KanziString, Error>
Methods from Deref<Target = Trigger>
pub fn add_action(&self, action: &Action) -> Result<(), Error>
pub fn add_action(&self, action: &Action) -> Result<(), Error>
Adds an action to the trigger.
pub fn invoke_actions(&self) -> Result<(), Error>
pub fn invoke_actions(&self) -> Result<(), Error>
Invokes actions in the trigger.
pub fn get_actions_iterator(&self) -> Result<TriggerActionsIterator, Error>
pub fn get_actions_iterator(&self) -> Result<TriggerActionsIterator, Error>
Gets an iterator over actions invoked when trigger is triggered.
pub fn get_actions(&self) -> Result<Vec<Weak<Action>>, Error>
pub fn get_actions(&self) -> Result<Vec<Weak<Action>>, Error>
Gets a list of actions invoked when trigger is triggered.
pub fn add_condition(&self, condition: &Condition) -> Result<(), Error>
pub fn add_condition(&self, condition: &Condition) -> Result<(), Error>
Adds a condition to the trigger.
pub fn check_conditions(&self) -> Result<bool, Error>
pub fn check_conditions(&self) -> Result<bool, Error>
Checks against all conditions in the trigger.
pub fn get_conditions_iterator(
&self,
) -> Result<TriggerConditionsIterator, Error>
pub fn get_conditions_iterator( &self, ) -> Result<TriggerConditionsIterator, Error>
Gets an iterator over conditions evaluated when trigger is triggered.
Methods from Deref<Target = NodeComponent>
pub fn get_name(&self) -> Result<KanziString, Error>
pub fn get_name(&self) -> Result<KanziString, Error>
See: NAME_PROPERTY
pub fn get_node(&self) -> Result<Option<Weak<Node>>, Error>
pub fn get_node(&self) -> Result<Option<Weak<Node>>, Error>
Returns the node the node component is attached to
or None if node component is not attached to a node.
pub fn get_state(&self) -> Result<NodeComponentState, Error>
pub fn get_state(&self) -> Result<NodeComponentState, Error>
Gets the state of node component indicating if component is attached to a node, detached from any node or in process of attaching/detaching.
Methods from Deref<Target = Object>
pub fn as_ptr(&self) -> *mut ObjectWrapper
pub fn as_wrapper(&self) -> &ObjectWrapper
pub fn as_object(&self) -> &Object
pub fn as_object(&self) -> &Object
Represents any type inheriting from Object as &Object.
This is useful for comparisions when PartialEq traits failed to compare objects of
different types.
let child = screen.get_child(0)?;
let parent = child.get_parent()?.into_error(ErrorKind::ObjectNotFound)?;
// assert_eq!(screen, parent); // <- Fails to compile!
assert_eq!(screen.as_object(), parent.as_object());pub fn get_native(&self) -> Result<NonNull<c_void>, Error>
pub fn get_native(&self) -> Result<NonNull<c_void>, Error>
Gets a pointer to the backing C++ instance.
pub fn get_property<T>(
&self,
property_type: &PropertyType<T>,
) -> Result<<T as VariantConstraint>::RetArg, Error>where
T: PropertyTypeConstraint,
pub fn get_property<T>(
&self,
property_type: &PropertyType<T>,
) -> Result<<T as VariantConstraint>::RetArg, Error>where
T: PropertyTypeConstraint,
Returns the current value of a property disregarding modifiers.
Base value is affected by the following inputs where the highest entry in the list determines the base value:
- Local value set with setProperty or loaded from kzb
- Value set by a style affecting the property.
- Value defined by class metadata.
Modifiers are not applied, the highest-priority base value is returned.
If no inputs to the property value can be established the system returns the value default value from property type metadata.
Arguments
property_type- The property type identifying the property to retrieve.
Returns
The evaluated property value.
pub fn get_optional_property<T>(
&self,
property_type: &PropertyType<T>,
) -> Result<Option<<T as VariantConstraint>::RetArg>, Error>where
T: PropertyTypeConstraint,
pub fn get_optional_property<T>(
&self,
property_type: &PropertyType<T>,
) -> Result<Option<<T as VariantConstraint>::RetArg>, Error>where
T: PropertyTypeConstraint,
Returns the current value of a property disregarding modifiers, but does not default to the value in property metadata if there are no inputs to the property value.
If there is no value sources, None is returned.
If no inputs to the property value can be established the system returns the value default value from property type metadata.
Arguments
property_type- The property type identifying the property to retrieve.
Returns
The evaluated property value.
pub fn set_property<T>(
&self,
property_type: &PropertyType<T>,
value: <T as VariantConstraint>::DataArg<'_>,
) -> Result<(), Error>where
T: PropertyTypeConstraint,
pub fn set_property<T>(
&self,
property_type: &PropertyType<T>,
value: <T as VariantConstraint>::DataArg<'_>,
) -> Result<(), Error>where
T: PropertyTypeConstraint,
Sets the local value of a property type.
pub fn has_value<T>(
&self,
property_type: &PropertyType<T>,
) -> Result<bool, Error>where
T: PropertyTypeConstraint,
pub fn has_value<T>(
&self,
property_type: &PropertyType<T>,
) -> Result<bool, Error>where
T: PropertyTypeConstraint,
Evaluates whether there are any inputs into the property value. Both value sources and modifiers are taken into account.
Returns
Returns true if there are inputs into the property value, false otherwise.
pub fn remove_local_value<T>(
&self,
property_type: &PropertyType<T>,
) -> Result<(), Error>where
T: PropertyTypeConstraint,
pub fn remove_local_value<T>(
&self,
property_type: &PropertyType<T>,
) -> Result<(), Error>where
T: PropertyTypeConstraint,
Removes the local value associated with the property.
pub fn get_metaclass(&self) -> Result<Metaclass, Error>
pub fn get_metaclass(&self) -> Result<Metaclass, Error>
Returns the metaclass of the dynamic type of the object.
pub fn get_domain(&self) -> Result<Domain, Error>
pub fn get_domain(&self) -> Result<Domain, Error>
Returns the domain the object belongs to.
pub fn set_flag_keep_during_patching<T>(
&self,
property_type: &PropertyType<T>,
) -> Result<(), Error>where
T: PropertyTypeConstraint,
pub fn set_flag_keep_during_patching<T>(
&self,
property_type: &PropertyType<T>,
) -> Result<(), Error>where
T: PropertyTypeConstraint,
Sets the flag to indicate that the property was loaded from KZB.
pub fn debug_string(&self) -> Result<String, Error>
pub fn debug_string(&self) -> Result<String, Error>
Builds a string representation of the object intended for debugging purposes.